// #define TOOL_BUTTON_SIZE 28

// GTK uses 24 for icon sizes by default.  Spacing adjust to keep the
// toolbar the same as other GTK applications.  If we want that, use
// these defines instead:
//#define AUX_BUTTON_SIZE 24
//#define AUX_SPACING 2

// #define AUX_BUTTON_SIZE 20
#define AUX_SPACING 3

#define AUX_BETWEEN_BUTTON_GROUPS 7
#define AUX_BETWEEN_SPINBUTTONS 0
#define AUX_SPINBUTTON_WIDTH 57
#define AUX_SPINBUTTON_HEIGHT 20
#define AUX_OPTION_MENU_WIDTH 55
#define AUX_OPTION_MENU_HEIGHT 20
#define AUX_MENU_ITEM_WIDTH 32
#define AUX_MENU_ITEM_HEIGHT 18

#define SPIN_STEP 0.1
#define SPIN_PAGE_STEP 5.0

#define BOTTOM_BAR_HEIGHT 20
#define BOTTOM_BUTTON_SIZE 14

#define STATUS_BAR_FONT_SIZE 10000

#define STATUS_ZOOM_FONT_SIZE 7700
#define STATUS_ZOOM_WIDTH 57

#define STATUS_COORD_FONT_SIZE 7700
#define STATUS_COORD_SKIP 1
#define STATUS_COORD_WIDTH 84

#define STATUS_LAYER_FONT_SIZE 7700

#define RULER_WIDTH           12
#define RULER_HEIGHT          12
#define RULER_FONT_SIZE 6500
#define RULER_FONT_VERTICAL_SPACING 1.2

/*
  Local Variables:
  mode:c++
  c-file-style:"stroustrup"
  c-file-offsets:((innamespace . 0)(inline-open . 0))
  indent-tabs-mode:nil
  fill-column:99
  End:
*/
// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
